#include "itkLinear2DIndexComparator.h"
#include "itkLinear2DIndexInterpolator.h"

namespace itk
{

bool
Linear2DIndexComparator::
operator()(const itk::Linear2DIndexInterpolator &l1, const itk::Linear2DIndexInterpolator &l2) const
{
  // Decide by x component if possible
  int x1 = l1.GetX();
  int x2 = l2.GetX();
  if (x1 != x2) return x1 < x2;
  
  // Decide by y component if possible
  int y1 = l1.GetY();
  int y2 = l2.GetY();
  if (y1 != y2) return y1 < y2;

  // Last measure: Decide by error term
  float e1 = l1.YError();
  float e2 = l2.YError();
  return (e1 < e2);
}

bool
Linear2DIndexComparator::
operator()(const itk::Linear2DIndexInterpolator *l1, const itk::Linear2DIndexInterpolator *l2) const
{
  return this->operator()(*l1, *l2);
}

} // end namespace itk
