#ifndef __itkLinear2DIndexComparator_h
#define __itkLinear2DIndexComparator_h

#include "itkMacro.h"

namespace itk
{

// Forward declaration of Linear2DIndexInterpolator so it can be used as an
// argument for the comparison
class Linear2DIndexInterpolator;

/**
 * \class Linear2DIndexComparator
 * \brief Order relation for Linear2DIndexInterpolator
 *
 * Linear2DIndexComparator provides a "less than" relation for
 * Linear2DIndexInterpolators l1 and l2. l1 and l2 have an x value, a y value
 * and an error term e. The order of l1 and l2 depends lexicographically on
 * these values: l1 < l2 := (x1 < x2) || 
 *              (x1 == x2 && y1 < y2) ||
 *  (x1 == x2 && y1 == y2 && e1 < e2) 
 *
 * The main purpose of this class is the application in polygon scan
 * conversion.
 * 
 * This class was contributed by Benjamin King, Experimentelle Radiologie,
 * Medizinische Hochschule Hannover
 * 
 * \sa Linear2DIndexInterpolator, PolygonScanConversionIterator
 */
class Linear2DIndexComparator {
public:
  /** Standard class typedefs. */
  typedef Linear2DIndexComparator Self;

  /** Run-time type information */
  itkTypeMacro(Linear2DIndexComparator, None);

  /** Return true iff first element is less than the second */
  bool operator()(const itk::Linear2DIndexInterpolator &, const itk::Linear2DIndexInterpolator &) const;

  /** Return true iff first element is less than the second */
  bool operator()(const itk::Linear2DIndexInterpolator *, const itk::Linear2DIndexInterpolator *) const;
};

} // end namespace itk
#endif
